# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .update_service_pb2 import GetTransactionByEventIdRequest, GetTransactionByIdRequest, GetTransactionResponse, GetTransactionTreeResponse, GetUpdateTreesResponse, GetUpdatesRequest, GetUpdatesResponse

__all__ = [
    "UpdateServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class UpdateServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _UpdateServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _UpdateServiceAsyncStub: ...  # type: ignore
    def GetUpdates(self, __1: GetUpdatesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[_grpc.CallIterator[GetUpdatesResponse], _grpc_aio.UnaryStreamCall[_typing.Any, GetUpdatesResponse]]: ...
    def GetUpdateTrees(self, __1: GetUpdatesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[_grpc.CallIterator[GetUpdateTreesResponse], _grpc_aio.UnaryStreamCall[_typing.Any, GetUpdateTreesResponse]]: ...
    def GetTransactionTreeByEventId(self, __1: GetTransactionByEventIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetTransactionTreeResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetTransactionTreeResponse]]: ...
    def GetTransactionTreeById(self, __1: GetTransactionByIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetTransactionTreeResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetTransactionTreeResponse]]: ...
    def GetTransactionByEventId(self, __1: GetTransactionByEventIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetTransactionResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetTransactionResponse]]: ...
    def GetTransactionById(self, __1: GetTransactionByIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetTransactionResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetTransactionResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _UpdateServiceBlockingStub(UpdateServiceStub):
    def GetUpdates(self, __1: GetUpdatesRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[GetUpdatesResponse]: ...
    def GetUpdateTrees(self, __1: GetUpdatesRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[GetUpdateTreesResponse]: ...
    def GetTransactionTreeByEventId(self, __1: GetTransactionByEventIdRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetTransactionTreeResponse: ...
    def GetTransactionTreeById(self, __1: GetTransactionByIdRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetTransactionTreeResponse: ...
    def GetTransactionByEventId(self, __1: GetTransactionByEventIdRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetTransactionResponse: ...
    def GetTransactionById(self, __1: GetTransactionByIdRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetTransactionResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _UpdateServiceAsyncStub(UpdateServiceStub):
    def GetUpdates(self, __1: GetUpdatesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, GetUpdatesResponse]: ...  # type: ignore
    def GetUpdateTrees(self, __1: GetUpdatesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, GetUpdateTreesResponse]: ...  # type: ignore
    def GetTransactionTreeByEventId(self, __1: GetTransactionByEventIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetTransactionTreeResponse]: ...  # type: ignore
    def GetTransactionTreeById(self, __1: GetTransactionByIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetTransactionTreeResponse]: ...  # type: ignore
    def GetTransactionByEventId(self, __1: GetTransactionByEventIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetTransactionResponse]: ...  # type: ignore
    def GetTransactionById(self, __1: GetTransactionByIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetTransactionResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SequencerApiType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    Grpc: _ClassVar[SequencerApiType]
Grpc: SequencerApiType

class SequencerConnection(_message.Message):
    __slots__ = ("grpc", "alias")
    class Grpc(_message.Message):
        __slots__ = ("connections", "transportSecurity", "customTrustCertificates")
        CONNECTIONS_FIELD_NUMBER: _ClassVar[int]
        TRANSPORTSECURITY_FIELD_NUMBER: _ClassVar[int]
        CUSTOMTRUSTCERTIFICATES_FIELD_NUMBER: _ClassVar[int]
        connections: _containers.RepeatedScalarFieldContainer[str]
        transportSecurity: bool
        customTrustCertificates: _wrappers_pb2.BytesValue
        def __init__(self, connections: _Optional[_Iterable[str]] = ..., transportSecurity: bool = ..., customTrustCertificates: _Optional[_Union[_wrappers_pb2.BytesValue, _Mapping]] = ...) -> None: ...
    GRPC_FIELD_NUMBER: _ClassVar[int]
    ALIAS_FIELD_NUMBER: _ClassVar[int]
    grpc: SequencerConnection.Grpc
    alias: str
    def __init__(self, grpc: _Optional[_Union[SequencerConnection.Grpc, _Mapping]] = ..., alias: _Optional[str] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from datetime import timedelta
import sys
from typing import Collection, Literal, Optional, TypedDict

from ..prim import Parties, Party, TimeDeltaLike, to_timedelta
from .auth import TokenOrTokenProvider, get_token, parse_token

if sys.version_info >= (3, 11):
    from typing import Self
else:
    from typing_extensions import Self

__all__ = [
    "CallParameters",
    "ReadCallParameters",
    "WriteCallParameters",
    "AnyCallParameters",
    "CallContext",
    "CachedParameters",
    "ConnectionParameters",
]


class CallParameters(TypedDict):
    token: Optional[TokenOrTokenProvider]
    timeout: Optional[TimeDeltaLike]


class ReadCallParameters(CallParameters):
    read_as: Optional[Parties]
    user_id: Optional[str]


class WriteCallParameters(ReadCallParameters):
    workflow_id: Optional[str]
    command_id: Optional[str]
    act_as: Optional[Parties]
    application_name: Optional[str]


class AnyCallParameters(TypedDict, total=False):
    """
    AnyCallParameters is the superset of all possible arguments that can be specified at
    call time.

    Currently, this is equivalent to WriteCallParameters, but we define a new type to
    clarify the intent of code.
    """

    token: Optional[TokenOrTokenProvider]
    timeout: Optional[TimeDeltaLike]
    read_as: Optional[Parties]
    user_id: Optional[str]
    workflow_id: Optional[str]
    command_id: Optional[str]
    act_as: Optional[Parties]
    application_name: Optional[str]


class CachedParameters(TypedDict):
    """
    Parameters that are cached between successive calls. The fields of this type are
    _similar_, but not exactly the same as :class:`AnyCallParameters` and
    :class:`ConnectionParameters`.
    """

    read_as: Optional[Collection[Party]]
    act_as: Optional[Collection[Party]]
    ledger_id: Optional[str]
    user_id_or_application_name: Optional[str]
    token: Optional[str]


class ConnectionParameters(TypedDict):
    """
    Parameters that are supplied at connection construction time.
    """

    read_as: Optional[Collection[Party]]
    act_as: Optional[Collection[Party]]
    ledger_id: Optional[str]
    user_id_or_application_name: Optional[str]
    token: Optional[TokenOrTokenProvider]
    timeout: Optional[timedelta]


class CallContext:
    """
    Contextual information as it relates to a single logical Ledger API call.
    """

    @classmethod
    def compute(
        cls,
        call: AnyCallParameters,
        cache: Optional[CachedParameters],
        connection: ConnectionParameters,
    ) -> Self:
        """
        Compute the values that should be effective for a logical Ledger API call, based on what
        was supplied at call time, previously cached values, or at connection time.

        Data is consulted in the following priority:
         * values supplied at _call_ time always win
            * mutually related fields (read-as/act-as/token/user-id/application-name) must be
              consistent if multiple are specified
         * values that come from the cache come next, but only if the token (as computed from
           either the current call's ``token`` or the current connection's ``token`` value) is
           the same token as the previous call; otherwise, the cache is ignored
         * values that come from the connection level
         * a handful of values (``timeout``, ``application_name``) are defaulted here if not
           specified elsewhere.

        :param call:
        :param cache:
        :param connection:
        :return:
        """
        # compute the effective token for this call
        token = get_token(call.get("token"))
        token_level: Literal["call", "connection"] = "call"
        if token is None:
            token = get_token(connection.get("token"))
            token_level = "connection"

        # depending on whether read_as/act_as/ledger_id/user_id/application_name are specified,
        # the token itself also participates in defaulting values
        parsed_token = parse_token(token) if token is not None else None

        # if we were supplied a cache, but it differs from the token that we computed,
        # then throw away the cache because we can't use any of its values
        if cache is not None and cache.get("token") != token:
            cache = None

        ledger_id = connection.get("ledger_id")
        if ledger_id is None and parsed_token is not None and parsed_token.token_version == 1:
            # Daml v1 tokens happen to have ledger ID stored in them, so the token can be used
            # to identify the Ledger ID
            ledger_id = parsed_token.ledger_id

        user_id_or_application_name: Optional[str] = None

        read_as = call.get("read_as")
        if read_as is None and cache is not None:
            read_as = cache.get("read_as")
        if read_as is None:
            read_as = connection.get("read_as")

        act_as = call.get("act_as")
        if act_as is None and cache is not None:
            act_as = cache.get("act_as")
        if act_as is None:
            act_as = connection.get("act_as")

        if read_as is None and act_as is None:
            # if we can't find a read-as/act-as at the call site, in our cache, or at the
            # connection level, maybe the token supplies the information we need
            if parsed_token is not None and parsed_token.token_version == 1:
                read_as = parsed_token.read_as
                act_as = parsed_token.act_as

        # In Daml 2, application_name became overloaded to _also_ mean user_id.
        # Prefer that people use user_id, as that's going to be the standard in Daml 3.
        call_user_id = call.get("user_id")
        if call_user_id is not None:
            if call.get("application_name") is not None:
                raise ValueError("cannot specify user_id and application_name at the same time")
            user_id_or_application_name = call_user_id
        if user_id_or_application_name is None and cache is not None:
            user_id_or_application_name = cache.get("user_id_or_application_name")
        if user_id_or_application_name is None:
            user_id_or_application_name = connection.get("user_id_or_application_name")
        if user_id_or_application_name is None and parsed_token is not None:
            # as a last resort, if we can't find a user_id/application_id at any level,
            # try to extract it from the token
            if parsed_token.token_version == 1:
                user_id_or_application_name = parsed_token.application_name
            elif parsed_token.token_version == 2:
                user_id_or_application_name = parsed_token.user_id

        # compute the effective timeout for this call
        call_timeout = call.get("timeout")
        if call_timeout is not None:
            timeout = to_timedelta(call_timeout)
        else:
            connection_timeout = connection.get("timeout")
            if connection_timeout is not None:
                timeout = to_timedelta(connection_timeout)
            else:
                timeout = timedelta(seconds=30)

        return cls(
            workflow_id=call.get("workflow_id"),
            command_id=call.get("command_id"),
            read_as=read_as,
            act_as=act_as,
            ledger_id=ledger_id,
            user_id_or_application_name=user_id_or_application_name,
            token=token,
            timeout=timeout,
        )

    def __init__(
        self,
        workflow_id,
        command_id,
        read_as,
        act_as,
        ledger_id,
        user_id_or_application_name,
        token,
        timeout,
    ) -> None:
        self.workflow_id = workflow_id
        self.command_id = command_id
        self.read_as = read_as
        self.act_as = act_as
        self.ledger_id = ledger_id
        self.user_id_or_application_name = user_id_or_application_name
        self.token = token
        self.timeout = timeout

    @property
    def timeout_seconds(self) -> float:
        """
        Return the effective timeout for this call, in seconds.
        """
        return self.timeout.total_seconds()

    def get_cache(self) -> CachedParameters:
        """
        Return a :class:`CachedParameters` of values that might save us time in a subsequent
        call to the Ledger API.
        """
        return {
            "read_as": self.read_as,
            "act_as": self.act_as,
            "ledger_id": self.ledger_id,
            "user_id_or_application_name": self.user_id_or_application_name,
            "token": self.token,
        }



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/topology/admin/v0/topology_aggregation_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/topology/admin/v0/topology_aggregation_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....crypto.v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from ....protocol.v0 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_topology__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLcom/digitalasset/canton/topology/admin/v0/topology_aggregation_service.proto\x12)com.digitalasset.canton.topology.admin.v0\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1a\x32\x63om/digitalasset/canton/protocol/v0/topology.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd2\x01\n\x12ListPartiesRequest\x12/\n\x05\x61s_of\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x61sOf\x12\x14\n\x05limit\x18\x02 \x01(\x05R\x05limit\x12#\n\rfilter_domain\x18\x03 \x01(\tR\x0c\x66ilterDomain\x12!\n\x0c\x66ilter_party\x18\x04 \x01(\tR\x0b\x66ilterParty\x12-\n\x12\x66ilter_participant\x18\x05 \x01(\tR\x11\x66ilterParticipant\"\xdf\x04\n\x13ListPartiesResponse\x12_\n\x07results\x18\x02 \x03(\x0b\x32\x45.com.digitalasset.canton.topology.admin.v0.ListPartiesResponse.ResultR\x07results\x1a\xe6\x03\n\x06Result\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12|\n\x0cparticipants\x18\x02 \x03(\x0b\x32X.com.digitalasset.canton.topology.admin.v0.ListPartiesResponse.Result.ParticipantDomainsR\x0cparticipants\x1a\xc7\x02\n\x12ParticipantDomains\x12 \n\x0bparticipant\x18\x01 \x01(\tR\x0bparticipant\x12\x84\x01\n\x07\x64omains\x18\x02 \x03(\x0b\x32j.com.digitalasset.canton.topology.admin.v0.ListPartiesResponse.Result.ParticipantDomains.DomainPermissionsR\x07\x64omains\x1a\x87\x01\n\x11\x44omainPermissions\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12Z\n\npermission\x18\x02 \x01(\x0e\x32:.com.digitalasset.canton.protocol.v0.ParticipantPermissionR\npermission\"\xe6\x01\n\x14ListKeyOwnersRequest\x12/\n\x05\x61s_of\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x61sOf\x12\x14\n\x05limit\x18\x02 \x01(\x05R\x05limit\x12#\n\rfilter_domain\x18\x03 \x01(\tR\x0c\x66ilterDomain\x12\x31\n\x15\x66ilter_key_owner_type\x18\x04 \x01(\tR\x12\x66ilterKeyOwnerType\x12/\n\x14\x66ilter_key_owner_uid\x18\x05 \x01(\tR\x11\x66ilterKeyOwnerUid\"\xf3\x02\n\x15ListKeyOwnersResponse\x12\x61\n\x07results\x18\x01 \x03(\x0b\x32G.com.digitalasset.canton.topology.admin.v0.ListKeyOwnersResponse.ResultR\x07results\x1a\xf6\x01\n\x06Result\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12\x1b\n\tkey_owner\x18\x02 \x01(\tR\x08keyOwner\x12V\n\x0csigning_keys\x18\x03 \x03(\x0b\x32\x33.com.digitalasset.canton.crypto.v0.SigningPublicKeyR\x0bsigningKeys\x12_\n\x0f\x65ncryption_keys\x18\x04 \x03(\x0b\x32\x36.com.digitalasset.canton.crypto.v0.EncryptionPublicKeyR\x0e\x65ncryptionKeys2\xc0\x02\n\x1aTopologyAggregationService\x12\x8c\x01\n\x0bListParties\x12=.com.digitalasset.canton.topology.admin.v0.ListPartiesRequest\x1a>.com.digitalasset.canton.topology.admin.v0.ListPartiesResponse\x12\x92\x01\n\rListKeyOwners\x12?.com.digitalasset.canton.topology.admin.v0.ListKeyOwnersRequest\x1a@.com.digitalasset.canton.topology.admin.v0.ListKeyOwnersResponseBZZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.topology.admin.v0.topology_aggregation_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v0'
  _globals['_LISTPARTIESREQUEST']._serialized_start=257
  _globals['_LISTPARTIESREQUEST']._serialized_end=467
  _globals['_LISTPARTIESRESPONSE']._serialized_start=470
  _globals['_LISTPARTIESRESPONSE']._serialized_end=1077
  _globals['_LISTPARTIESRESPONSE_RESULT']._serialized_start=591
  _globals['_LISTPARTIESRESPONSE_RESULT']._serialized_end=1077
  _globals['_LISTPARTIESRESPONSE_RESULT_PARTICIPANTDOMAINS']._serialized_start=750
  _globals['_LISTPARTIESRESPONSE_RESULT_PARTICIPANTDOMAINS']._serialized_end=1077
  _globals['_LISTPARTIESRESPONSE_RESULT_PARTICIPANTDOMAINS_DOMAINPERMISSIONS']._serialized_start=942
  _globals['_LISTPARTIESRESPONSE_RESULT_PARTICIPANTDOMAINS_DOMAINPERMISSIONS']._serialized_end=1077
  _globals['_LISTKEYOWNERSREQUEST']._serialized_start=1080
  _globals['_LISTKEYOWNERSREQUEST']._serialized_end=1310
  _globals['_LISTKEYOWNERSRESPONSE']._serialized_start=1313
  _globals['_LISTKEYOWNERSRESPONSE']._serialized_end=1684
  _globals['_LISTKEYOWNERSRESPONSE_RESULT']._serialized_start=1438
  _globals['_LISTKEYOWNERSRESPONSE_RESULT']._serialized_end=1684
  _globals['_TOPOLOGYAGGREGATIONSERVICE']._serialized_start=1687
  _globals['_TOPOLOGYAGGREGATIONSERVICE']._serialized_end=2007
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/domain/v30/sequencer_connection.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/admin/domain/v30/sequencer_connection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCcom/digitalasset/canton/admin/domain/v30/sequencer_connection.proto\x12(com.digitalasset.canton.admin.domain.v30\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xbd\x02\n\x13SequencerConnection\x12X\n\x04grpc\x18\x02 \x01(\x0b\x32\x42.com.digitalasset.canton.admin.domain.v30.SequencerConnection.GrpcH\x00R\x04grpc\x12\x14\n\x05\x61lias\x18\x03 \x01(\tR\x05\x61lias\x1a\xad\x01\n\x04Grpc\x12 \n\x0b\x63onnections\x18\x01 \x03(\tR\x0b\x63onnections\x12,\n\x11transportSecurity\x18\x02 \x01(\x08R\x11transportSecurity\x12U\n\x17\x63ustomTrustCertificates\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.BytesValueR\x17\x63ustomTrustCertificatesB\x06\n\x04type\"\xd9\x02\n\x14SequencerConnections\x12r\n\x15sequencer_connections\x18\x01 \x03(\x0b\x32=.com.digitalasset.canton.admin.domain.v30.SequencerConnectionR\x14sequencerConnections\x12\x38\n\x17sequencerTrustThreshold\x18\x02 \x01(\rR\x17sequencerTrustThreshold\x12\x92\x01\n submission_request_amplification\x18\x03 \x01(\x0b\x32H.com.digitalasset.canton.admin.domain.v30.SubmissionRequestAmplificationR\x1esubmissionRequestAmplification\"o\n\x1eSubmissionRequestAmplification\x12\x16\n\x06\x66\x61\x63tor\x18\x01 \x01(\rR\x06\x66\x61\x63tor\x12\x35\n\x08patience\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x08patience*O\n\x1dSequencerConnectionValidation\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x07\n\x03\x41LL\x10\x03\x42YZWgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/domain/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.domain.v30.sequencer_connection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZWgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/domain/v30'
  _globals['_SEQUENCERCONNECTIONVALIDATION']._serialized_start=958
  _globals['_SEQUENCERCONNECTIONVALIDATION']._serialized_end=1037
  _globals['_SEQUENCERCONNECTION']._serialized_start=178
  _globals['_SEQUENCERCONNECTION']._serialized_end=495
  _globals['_SEQUENCERCONNECTION_GRPC']._serialized_start=314
  _globals['_SEQUENCERCONNECTION_GRPC']._serialized_end=487
  _globals['_SEQUENCERCONNECTIONS']._serialized_start=498
  _globals['_SEQUENCERCONNECTIONS']._serialized_end=843
  _globals['_SUBMISSIONREQUESTAMPLIFICATION']._serialized_start=845
  _globals['_SUBMISSIONREQUESTAMPLIFICATION']._serialized_end=956
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .ledger_sync_event_pb2 import BlindingInfo, CommandKind, CommandRejected, CompletionInfo, Configuration, ConfigurationChangeRejected, ConfigurationChanged, ContractsAdded, ContractsPurged, DivulgedContract, LedgerSyncEvent, NodeSeed, Parties, PartyAddedToParticipant, PartyAllocationRejected, PublicPackageUpload, PublicPackageUploadRejected, TimeModel, TransactionAccepted, TransactionMeta, TransferredIn, TransferredOut
from .submission_tracking_pb2 import SubmissionTrackingData, TransactionSubmissionTrackingData

__all__ = [
    "BlindingInfo",
    "CommandKind",
    "CommandRejected",
    "CompletionInfo",
    "Configuration",
    "ConfigurationChangeRejected",
    "ConfigurationChanged",
    "ContractsAdded",
    "ContractsPurged",
    "DivulgedContract",
    "LedgerSyncEvent",
    "NodeSeed",
    "Parties",
    "PartyAddedToParticipant",
    "PartyAllocationRejected",
    "PublicPackageUpload",
    "PublicPackageUploadRejected",
    "SubmissionTrackingData",
    "TimeModel",
    "TransactionAccepted",
    "TransactionMeta",
    "TransactionSubmissionTrackingData",
    "TransferredIn",
    "TransferredOut",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...crypto.v30 import crypto_pb2 as _crypto_pb2
from . import common_stable_pb2 as _common_stable_pb2
from . import merkle_pb2 as _merkle_pb2
from ...time.v30 import time_proof_pb2 as _time_proof_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TransferId(_message.Message):
    __slots__ = ("source_domain", "timestamp")
    SOURCE_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    source_domain: str
    timestamp: int
    def __init__(self, source_domain: _Optional[str] = ..., timestamp: _Optional[int] = ...) -> None: ...

class TransferOutCommonData(_message.Message):
    __slots__ = ("salt", "source_domain", "stakeholders", "admin_parties", "uuid", "source_mediator_group", "submitter_metadata")
    SALT_FIELD_NUMBER: _ClassVar[int]
    SOURCE_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    STAKEHOLDERS_FIELD_NUMBER: _ClassVar[int]
    ADMIN_PARTIES_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_MEDIATOR_GROUP_FIELD_NUMBER: _ClassVar[int]
    SUBMITTER_METADATA_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    source_domain: str
    stakeholders: _containers.RepeatedScalarFieldContainer[str]
    admin_parties: _containers.RepeatedScalarFieldContainer[str]
    uuid: str
    source_mediator_group: int
    submitter_metadata: TransferSubmitterMetadata
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., source_domain: _Optional[str] = ..., stakeholders: _Optional[_Iterable[str]] = ..., admin_parties: _Optional[_Iterable[str]] = ..., uuid: _Optional[str] = ..., source_mediator_group: _Optional[int] = ..., submitter_metadata: _Optional[_Union[TransferSubmitterMetadata, _Mapping]] = ...) -> None: ...

class TransferViewTree(_message.Message):
    __slots__ = ("common_data", "participant_data")
    COMMON_DATA_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_DATA_FIELD_NUMBER: _ClassVar[int]
    common_data: bytes
    participant_data: _merkle_pb2.BlindableNode
    def __init__(self, common_data: _Optional[bytes] = ..., participant_data: _Optional[_Union[_merkle_pb2.BlindableNode, _Mapping]] = ...) -> None: ...

class TransferInMediatorMessage(_message.Message):
    __slots__ = ("tree", "submitting_participant_signature")
    TREE_FIELD_NUMBER: _ClassVar[int]
    SUBMITTING_PARTICIPANT_SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    tree: TransferViewTree
    submitting_participant_signature: _crypto_pb2.Signature
    def __init__(self, tree: _Optional[_Union[TransferViewTree, _Mapping]] = ..., submitting_participant_signature: _Optional[_Union[_crypto_pb2.Signature, _Mapping]] = ...) -> None: ...

class TransferOutMediatorMessage(_message.Message):
    __slots__ = ("tree", "submitting_participant_signature")
    TREE_FIELD_NUMBER: _ClassVar[int]
    SUBMITTING_PARTICIPANT_SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    tree: TransferViewTree
    submitting_participant_signature: _crypto_pb2.Signature
    def __init__(self, tree: _Optional[_Union[TransferViewTree, _Mapping]] = ..., submitting_participant_signature: _Optional[_Union[_crypto_pb2.Signature, _Mapping]] = ...) -> None: ...

class TransferInCommonData(_message.Message):
    __slots__ = ("salt", "target_domain", "stakeholders", "uuid", "target_mediator_group", "submitter_metadata")
    SALT_FIELD_NUMBER: _ClassVar[int]
    TARGET_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    STAKEHOLDERS_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    TARGET_MEDIATOR_GROUP_FIELD_NUMBER: _ClassVar[int]
    SUBMITTER_METADATA_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    target_domain: str
    stakeholders: _containers.RepeatedScalarFieldContainer[str]
    uuid: str
    target_mediator_group: int
    submitter_metadata: TransferSubmitterMetadata
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., target_domain: _Optional[str] = ..., stakeholders: _Optional[_Iterable[str]] = ..., uuid: _Optional[str] = ..., target_mediator_group: _Optional[int] = ..., submitter_metadata: _Optional[_Union[TransferSubmitterMetadata, _Mapping]] = ...) -> None: ...

class TransferSubmitterMetadata(_message.Message):
    __slots__ = ("submitter", "submitting_participant_uid", "command_id", "submission_id", "application_id", "workflow_id")
    SUBMITTER_FIELD_NUMBER: _ClassVar[int]
    SUBMITTING_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    COMMAND_ID_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_ID_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    submitter: str
    submitting_participant_uid: str
    command_id: str
    submission_id: str
    application_id: str
    workflow_id: str
    def __init__(self, submitter: _Optional[str] = ..., submitting_participant_uid: _Optional[str] = ..., command_id: _Optional[str] = ..., submission_id: _Optional[str] = ..., application_id: _Optional[str] = ..., workflow_id: _Optional[str] = ...) -> None: ...

class TransferOutView(_message.Message):
    __slots__ = ("salt", "target_domain", "target_time_proof", "target_protocol_version", "transfer_counter", "creating_transaction_id", "contract")
    SALT_FIELD_NUMBER: _ClassVar[int]
    TARGET_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    TARGET_TIME_PROOF_FIELD_NUMBER: _ClassVar[int]
    TARGET_PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_COUNTER_FIELD_NUMBER: _ClassVar[int]
    CREATING_TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    target_domain: str
    target_time_proof: _time_proof_pb2.TimeProof
    target_protocol_version: int
    transfer_counter: int
    creating_transaction_id: bytes
    contract: _common_stable_pb2.SerializableContract
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., target_domain: _Optional[str] = ..., target_time_proof: _Optional[_Union[_time_proof_pb2.TimeProof, _Mapping]] = ..., target_protocol_version: _Optional[int] = ..., transfer_counter: _Optional[int] = ..., creating_transaction_id: _Optional[bytes] = ..., contract: _Optional[_Union[_common_stable_pb2.SerializableContract, _Mapping]] = ...) -> None: ...

class TransferInView(_message.Message):
    __slots__ = ("salt", "contract", "transfer_out_result_event", "creating_transaction_id", "source_protocol_version", "transfer_counter")
    SALT_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_OUT_RESULT_EVENT_FIELD_NUMBER: _ClassVar[int]
    CREATING_TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_COUNTER_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    contract: _common_stable_pb2.SerializableContract
    transfer_out_result_event: bytes
    creating_transaction_id: bytes
    source_protocol_version: int
    transfer_counter: int
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., contract: _Optional[_Union[_common_stable_pb2.SerializableContract, _Mapping]] = ..., transfer_out_result_event: _Optional[bytes] = ..., creating_transaction_id: _Optional[bytes] = ..., source_protocol_version: _Optional[int] = ..., transfer_counter: _Optional[int] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from google.protobuf.empty_pb2 import Empty
from grpc import aio as _grpc_aio

from .status_service_pb2 import GetLastErrorTraceRequest, GetLastErrorTraceResponse, GetLastErrorsRequest, GetLastErrorsResponse, HealthDumpChunk, HealthDumpRequest, NodeStatus, SetLogLevelRequest, SetLogLevelResponse

__all__ = [
    "StatusServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class StatusServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _StatusServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _StatusServiceAsyncStub: ...  # type: ignore
    def Status(self, __1: Empty, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[NodeStatus, _grpc_aio.UnaryUnaryCall[_typing.Any, NodeStatus]]: ...
    def HealthDump(self, __1: HealthDumpRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[_grpc.CallIterator[HealthDumpChunk], _grpc_aio.UnaryStreamCall[_typing.Any, HealthDumpChunk]]: ...
    def SetLogLevel(self, __1: SetLogLevelRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SetLogLevelResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SetLogLevelResponse]]: ...
    def GetLastErrors(self, __1: GetLastErrorsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetLastErrorsResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetLastErrorsResponse]]: ...
    def GetErrorTrace(self, __1: GetLastErrorTraceRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetLastErrorTraceResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetLastErrorTraceResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _StatusServiceBlockingStub(StatusServiceStub):
    def Status(self, __1: Empty, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> NodeStatus: ...
    def HealthDump(self, __1: HealthDumpRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[HealthDumpChunk]: ...
    def SetLogLevel(self, __1: SetLogLevelRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetLogLevelResponse: ...
    def GetLastErrors(self, __1: GetLastErrorsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetLastErrorsResponse: ...
    def GetErrorTrace(self, __1: GetLastErrorTraceRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetLastErrorTraceResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _StatusServiceAsyncStub(StatusServiceStub):
    def Status(self, __1: Empty, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, NodeStatus]: ...  # type: ignore
    def HealthDump(self, __1: HealthDumpRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, HealthDumpChunk]: ...  # type: ignore
    def SetLogLevel(self, __1: SetLogLevelRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetLogLevelResponse]: ...  # type: ignore
    def GetLastErrors(self, __1: GetLastErrorsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetLastErrorsResponse]: ...  # type: ignore
    def GetErrorTrace(self, __1: GetLastErrorTraceRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetLastErrorTraceResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/pruning/admin/v0/pruning.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/pruning/admin/v0/pruning.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6com/digitalasset/canton/pruning/admin/v0/pruning.proto\x12(com.digitalasset.canton.pruning.admin.v0\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"{\n\x0bSetSchedule\x1a`\n\x07Request\x12U\n\x08schedule\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.pruning.admin.v0.PruningScheduleR\x08schedule\x1a\n\n\x08Response\"{\n\x0bGetSchedule\x1a\t\n\x07Request\x1a\x61\n\x08Response\x12U\n\x08schedule\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.pruning.admin.v0.PruningScheduleR\x08schedule\"\x91\x01\n\x16SetParticipantSchedule\x1ak\n\x07Request\x12`\n\x08schedule\x18\x01 \x01(\x0b\x32\x44.com.digitalasset.canton.pruning.admin.v0.ParticipantPruningScheduleR\x08schedule\x1a\n\n\x08Response\"\x91\x01\n\x16GetParticipantSchedule\x1a\t\n\x07Request\x1al\n\x08Response\x12`\n\x08schedule\x18\x01 \x01(\x0b\x32\x44.com.digitalasset.canton.pruning.admin.v0.ParticipantPruningScheduleR\x08schedule\"\x9c\x01\n\x0fPruningSchedule\x12\x12\n\x04\x63ron\x18\x01 \x01(\tR\x04\x63ron\x12<\n\x0cmax_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0bmaxDuration\x12\x37\n\tretention\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\tretention\"\xa7\x01\n\x1aParticipantPruningSchedule\x12U\n\x08schedule\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.pruning.admin.v0.PruningScheduleR\x08schedule\x12\x32\n\x15prune_internally_only\x18\x02 \x01(\x08R\x13pruneInternallyOnly\"&\n\rClearSchedule\x1a\t\n\x07Request\x1a\n\n\x08Response\"4\n\x07SetCron\x1a\x1d\n\x07Request\x12\x12\n\x04\x63ron\x18\x01 \x01(\tR\x04\x63ron\x1a\n\n\x08Response\"e\n\x0eSetMaxDuration\x1aG\n\x07Request\x12<\n\x0cmax_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0bmaxDuration\x1a\n\n\x08Response\"^\n\x0cSetRetention\x1a\x42\n\x07Request\x12\x37\n\tretention\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\tretention\x1a\n\n\x08Response\"\x7f\n\x16LocatePruningTimestamp\x1a\x1f\n\x07Request\x12\x14\n\x05index\x18\x01 \x01(\x05R\x05index\x1a\x44\n\x08Response\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestampBYZWgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/pruning/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.pruning.admin.v0.pruning_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZWgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/pruning/admin/v0'
  _globals['_SETSCHEDULE']._serialized_start=165
  _globals['_SETSCHEDULE']._serialized_end=288
  _globals['_SETSCHEDULE_REQUEST']._serialized_start=180
  _globals['_SETSCHEDULE_REQUEST']._serialized_end=276
  _globals['_SETSCHEDULE_RESPONSE']._serialized_start=278
  _globals['_SETSCHEDULE_RESPONSE']._serialized_end=288
  _globals['_GETSCHEDULE']._serialized_start=290
  _globals['_GETSCHEDULE']._serialized_end=413
  _globals['_GETSCHEDULE_REQUEST']._serialized_start=180
  _globals['_GETSCHEDULE_REQUEST']._serialized_end=189
  _globals['_GETSCHEDULE_RESPONSE']._serialized_start=316
  _globals['_GETSCHEDULE_RESPONSE']._serialized_end=413
  _globals['_SETPARTICIPANTSCHEDULE']._serialized_start=416
  _globals['_SETPARTICIPANTSCHEDULE']._serialized_end=561
  _globals['_SETPARTICIPANTSCHEDULE_REQUEST']._serialized_start=442
  _globals['_SETPARTICIPANTSCHEDULE_REQUEST']._serialized_end=549
  _globals['_SETPARTICIPANTSCHEDULE_RESPONSE']._serialized_start=278
  _globals['_SETPARTICIPANTSCHEDULE_RESPONSE']._serialized_end=288
  _globals['_GETPARTICIPANTSCHEDULE']._serialized_start=564
  _globals['_GETPARTICIPANTSCHEDULE']._serialized_end=709
  _globals['_GETPARTICIPANTSCHEDULE_REQUEST']._serialized_start=180
  _globals['_GETPARTICIPANTSCHEDULE_REQUEST']._serialized_end=189
  _globals['_GETPARTICIPANTSCHEDULE_RESPONSE']._serialized_start=601
  _globals['_GETPARTICIPANTSCHEDULE_RESPONSE']._serialized_end=709
  _globals['_PRUNINGSCHEDULE']._serialized_start=712
  _globals['_PRUNINGSCHEDULE']._serialized_end=868
  _globals['_PARTICIPANTPRUNINGSCHEDULE']._serialized_start=871
  _globals['_PARTICIPANTPRUNINGSCHEDULE']._serialized_end=1038
  _globals['_CLEARSCHEDULE']._serialized_start=1040
  _globals['_CLEARSCHEDULE']._serialized_end=1078
  _globals['_CLEARSCHEDULE_REQUEST']._serialized_start=180
  _globals['_CLEARSCHEDULE_REQUEST']._serialized_end=189
  _globals['_CLEARSCHEDULE_RESPONSE']._serialized_start=278
  _globals['_CLEARSCHEDULE_RESPONSE']._serialized_end=288
  _globals['_SETCRON']._serialized_start=1080
  _globals['_SETCRON']._serialized_end=1132
  _globals['_SETCRON_REQUEST']._serialized_start=1091
  _globals['_SETCRON_REQUEST']._serialized_end=1120
  _globals['_SETCRON_RESPONSE']._serialized_start=278
  _globals['_SETCRON_RESPONSE']._serialized_end=288
  _globals['_SETMAXDURATION']._serialized_start=1134
  _globals['_SETMAXDURATION']._serialized_end=1235
  _globals['_SETMAXDURATION_REQUEST']._serialized_start=1152
  _globals['_SETMAXDURATION_REQUEST']._serialized_end=1223
  _globals['_SETMAXDURATION_RESPONSE']._serialized_start=278
  _globals['_SETMAXDURATION_RESPONSE']._serialized_end=288
  _globals['_SETRETENTION']._serialized_start=1237
  _globals['_SETRETENTION']._serialized_end=1331
  _globals['_SETRETENTION_REQUEST']._serialized_start=1253
  _globals['_SETRETENTION_REQUEST']._serialized_end=1319
  _globals['_SETRETENTION_RESPONSE']._serialized_start=278
  _globals['_SETRETENTION_RESPONSE']._serialized_end=288
  _globals['_LOCATEPRUNINGTIMESTAMP']._serialized_start=1333
  _globals['_LOCATEPRUNINGTIMESTAMP']._serialized_end=1460
  _globals['_LOCATEPRUNINGTIMESTAMP_REQUEST']._serialized_start=1359
  _globals['_LOCATEPRUNINGTIMESTAMP_REQUEST']._serialized_end=1390
  _globals['_LOCATEPRUNINGTIMESTAMP_RESPONSE']._serialized_start=1392
  _globals['_LOCATEPRUNINGTIMESTAMP_RESPONSE']._serialized_end=1460
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .domain_time_service_pb2 import AwaitTimeRequest, AwaitTimeResponse, FetchTimeRequest, FetchTimeResponse
from .domain_time_service_pb2_grpc import DomainTimeServiceStub

__all__ = [
    "AwaitTimeRequest",
    "AwaitTimeResponse",
    "DomainTimeServiceStub",
    "FetchTimeRequest",
    "FetchTimeResponse",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import sequencer_service_pb2 as com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2
from ....protocol.v0 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2

GRPC_GENERATED_VERSION = '1.67.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in com/digitalasset/canton/domain/api/v0/sequencer_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SequencerServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SendAsync = channel.unary_unary(
                '/com.digitalasset.canton.domain.api.v0.SequencerService/SendAsync',
                request_serializer=com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2.SubmissionRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncResponse.FromString,
                _registered_method=True)
        self.SendAsyncSigned = channel.unary_unary(
                '/com.digitalasset.canton.domain.api.v0.SequencerService/SendAsyncSigned',
                request_serializer=com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2.SignedContent.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncSignedResponse.FromString,
                _registered_method=True)
        self.SendAsyncUnauthenticated = channel.unary_unary(
                '/com.digitalasset.canton.domain.api.v0.SequencerService/SendAsyncUnauthenticated',
                request_serializer=com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2.SubmissionRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncResponse.FromString,
                _registered_method=True)
        self.SendAsyncVersioned = channel.unary_unary(
                '/com.digitalasset.canton.domain.api.v0.SequencerService/SendAsyncVersioned',
                request_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncVersionedRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncSignedResponse.FromString,
                _registered_method=True)
        self.SendAsyncUnauthenticatedVersioned = channel.unary_unary(
                '/com.digitalasset.canton.domain.api.v0.SequencerService/SendAsyncUnauthenticatedVersioned',
                request_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncUnauthenticatedVersionedRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncResponse.FromString,
                _registered_method=True)
        self.Subscribe = channel.unary_stream(
                '/com.digitalasset.canton.domain.api.v0.SequencerService/Subscribe',
                request_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SubscriptionRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SubscriptionResponse.FromString,
                _registered_method=True)
        self.SubscribeVersioned = channel.unary_stream(
                '/com.digitalasset.canton.domain.api.v0.SequencerService/SubscribeVersioned',
                request_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SubscriptionRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.VersionedSubscriptionResponse.FromString,
                _registered_method=True)
        self.SubscribeUnauthenticated = channel.unary_stream(
                '/com.digitalasset.canton.domain.api.v0.SequencerService/SubscribeUnauthenticated',
                request_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SubscriptionRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SubscriptionResponse.FromString,
                _registered_method=True)
        self.SubscribeUnauthenticatedVersioned = channel.unary_stream(
                '/com.digitalasset.canton.domain.api.v0.SequencerService/SubscribeUnauthenticatedVersioned',
                request_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SubscriptionRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.VersionedSubscriptionResponse.FromString,
                _registered_method=True)
        self.Acknowledge = channel.unary_unary(
                '/com.digitalasset.canton.domain.api.v0.SequencerService/Acknowledge',
                request_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.AcknowledgeRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.AcknowledgeSigned = channel.unary_unary(
                '/com.digitalasset.canton.domain.api.v0.SequencerService/AcknowledgeSigned',
                request_serializer=com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2.SignedContent.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)


class SequencerServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SendAsync(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendAsyncSigned(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendAsyncUnauthenticated(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendAsyncVersioned(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendAsyncUnauthenticatedVersioned(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Subscribe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubscribeVersioned(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubscribeUnauthenticated(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubscribeUnauthenticatedVersioned(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Acknowledge(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AcknowledgeSigned(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SequencerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SendAsync': grpc.unary_unary_rpc_method_handler(
                    servicer.SendAsync,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2.SubmissionRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncResponse.SerializeToString,
            ),
            'SendAsyncSigned': grpc.unary_unary_rpc_method_handler(
                    servicer.SendAsyncSigned,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2.SignedContent.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncSignedResponse.SerializeToString,
            ),
            'SendAsyncUnauthenticated': grpc.unary_unary_rpc_method_handler(
                    servicer.SendAsyncUnauthenticated,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2.SubmissionRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncResponse.SerializeToString,
            ),
            'SendAsyncVersioned': grpc.unary_unary_rpc_method_handler(
                    servicer.SendAsyncVersioned,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncVersionedRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncSignedResponse.SerializeToString,
            ),
            'SendAsyncUnauthenticatedVersioned': grpc.unary_unary_rpc_method_handler(
                    servicer.SendAsyncUnauthenticatedVersioned,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncUnauthenticatedVersionedRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncResponse.SerializeToString,
            ),
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SubscriptionRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SubscriptionResponse.SerializeToString,
            ),
            'SubscribeVersioned': grpc.unary_stream_rpc_method_handler(
                    servicer.SubscribeVersioned,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SubscriptionRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.VersionedSubscriptionResponse.SerializeToString,
            ),
            'SubscribeUnauthenticated': grpc.unary_stream_rpc_method_handler(
                    servicer.SubscribeUnauthenticated,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SubscriptionRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SubscriptionResponse.SerializeToString,
            ),
            'SubscribeUnauthenticatedVersioned': grpc.unary_stream_rpc_method_handler(
                    servicer.SubscribeUnauthenticatedVersioned,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SubscriptionRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.VersionedSubscriptionResponse.SerializeToString,
            ),
            'Acknowledge': grpc.unary_unary_rpc_method_handler(
                    servicer.Acknowledge,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.AcknowledgeRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'AcknowledgeSigned': grpc.unary_unary_rpc_method_handler(
                    servicer.AcknowledgeSigned,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2.SignedContent.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.digitalasset.canton.domain.api.v0.SequencerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.digitalasset.canton.domain.api.v0.SequencerService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SequencerService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SendAsync(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.domain.api.v0.SequencerService/SendAsync',
            com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2.SubmissionRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SendAsyncSigned(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.domain.api.v0.SequencerService/SendAsyncSigned',
            com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2.SignedContent.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncSignedResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SendAsyncUnauthenticated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.domain.api.v0.SequencerService/SendAsyncUnauthenticated',
            com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2.SubmissionRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SendAsyncVersioned(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.domain.api.v0.SequencerService/SendAsyncVersioned',
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncVersionedRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncSignedResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SendAsyncUnauthenticatedVersioned(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.domain.api.v0.SequencerService/SendAsyncUnauthenticatedVersioned',
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncUnauthenticatedVersionedRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SendAsyncResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.digitalasset.canton.domain.api.v0.SequencerService/Subscribe',
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SubscriptionRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SubscriptionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SubscribeVersioned(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.digitalasset.canton.domain.api.v0.SequencerService/SubscribeVersioned',
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SubscriptionRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.VersionedSubscriptionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SubscribeUnauthenticated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.digitalasset.canton.domain.api.v0.SequencerService/SubscribeUnauthenticated',
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SubscriptionRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SubscriptionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SubscribeUnauthenticatedVersioned(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.digitalasset.canton.domain.api.v0.SequencerService/SubscribeUnauthenticatedVersioned',
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.SubscriptionRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.VersionedSubscriptionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Acknowledge(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.domain.api.v0.SequencerService/Acknowledge',
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__service__pb2.AcknowledgeRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AcknowledgeSigned(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.domain.api.v0.SequencerService/AcknowledgeSigned',
            com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2.SignedContent.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....crypto.v0 import crypto_pb2 as _crypto_pb2
from ....protocol.v0 import sequencing_pb2 as _sequencing_pb2
from ....protocol.v0 import topology_pb2 as _topology_pb2
from ....protocol.v1 import sequencing_pb2 as _sequencing_pb2_1
from ....protocol.v2 import domain_params_pb2 as _domain_params_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AuthorizationSuccess(_message.Message):
    __slots__ = ("serialized",)
    SERIALIZED_FIELD_NUMBER: _ClassVar[int]
    serialized: bytes
    def __init__(self, serialized: _Optional[bytes] = ...) -> None: ...

class AdditionSuccess(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SignedTopologyTransactionAddition(_message.Message):
    __slots__ = ("serialized",)
    SERIALIZED_FIELD_NUMBER: _ClassVar[int]
    serialized: bytes
    def __init__(self, serialized: _Optional[bytes] = ...) -> None: ...

class AuthorizationData(_message.Message):
    __slots__ = ("change", "signed_by", "replace_existing", "force_change")
    CHANGE_FIELD_NUMBER: _ClassVar[int]
    SIGNED_BY_FIELD_NUMBER: _ClassVar[int]
    REPLACE_EXISTING_FIELD_NUMBER: _ClassVar[int]
    FORCE_CHANGE_FIELD_NUMBER: _ClassVar[int]
    change: _topology_pb2.TopologyChangeOp
    signed_by: str
    replace_existing: bool
    force_change: bool
    def __init__(self, change: _Optional[_Union[_topology_pb2.TopologyChangeOp, str]] = ..., signed_by: _Optional[str] = ..., replace_existing: bool = ..., force_change: bool = ...) -> None: ...

class NamespaceDelegationAuthorization(_message.Message):
    __slots__ = ("authorization", "namespace", "fingerprint_of_authorized_key", "is_root_delegation")
    AUTHORIZATION_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    FINGERPRINT_OF_AUTHORIZED_KEY_FIELD_NUMBER: _ClassVar[int]
    IS_ROOT_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    authorization: AuthorizationData
    namespace: str
    fingerprint_of_authorized_key: str
    is_root_delegation: bool
    def __init__(self, authorization: _Optional[_Union[AuthorizationData, _Mapping]] = ..., namespace: _Optional[str] = ..., fingerprint_of_authorized_key: _Optional[str] = ..., is_root_delegation: bool = ...) -> None: ...

class IdentifierDelegationAuthorization(_message.Message):
    __slots__ = ("authorization", "identifier", "fingerprint_of_authorized_key")
    AUTHORIZATION_FIELD_NUMBER: _ClassVar[int]
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    FINGERPRINT_OF_AUTHORIZED_KEY_FIELD_NUMBER: _ClassVar[int]
    authorization: AuthorizationData
    identifier: str
    fingerprint_of_authorized_key: str
    def __init__(self, authorization: _Optional[_Union[AuthorizationData, _Mapping]] = ..., identifier: _Optional[str] = ..., fingerprint_of_authorized_key: _Optional[str] = ...) -> None: ...

class PartyToParticipantAuthorization(_message.Message):
    __slots__ = ("authorization", "side", "party", "participant", "permission")
    AUTHORIZATION_FIELD_NUMBER: _ClassVar[int]
    SIDE_FIELD_NUMBER: _ClassVar[int]
    PARTY_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    authorization: AuthorizationData
    side: _topology_pb2.RequestSide
    party: str
    participant: str
    permission: _topology_pb2.ParticipantPermission
    def __init__(self, authorization: _Optional[_Union[AuthorizationData, _Mapping]] = ..., side: _Optional[_Union[_topology_pb2.RequestSide, str]] = ..., party: _Optional[str] = ..., participant: _Optional[str] = ..., permission: _Optional[_Union[_topology_pb2.ParticipantPermission, str]] = ...) -> None: ...

class OwnerToKeyMappingAuthorization(_message.Message):
    __slots__ = ("authorization", "key_owner", "fingerprint_of_key", "key_purpose")
    AUTHORIZATION_FIELD_NUMBER: _ClassVar[int]
    KEY_OWNER_FIELD_NUMBER: _ClassVar[int]
    FINGERPRINT_OF_KEY_FIELD_NUMBER: _ClassVar[int]
    KEY_PURPOSE_FIELD_NUMBER: _ClassVar[int]
    authorization: AuthorizationData
    key_owner: str
    fingerprint_of_key: str
    key_purpose: _crypto_pb2.KeyPurpose
    def __init__(self, authorization: _Optional[_Union[AuthorizationData, _Mapping]] = ..., key_owner: _Optional[str] = ..., fingerprint_of_key: _Optional[str] = ..., key_purpose: _Optional[_Union[_crypto_pb2.KeyPurpose, str]] = ...) -> None: ...

class ParticipantDomainStateAuthorization(_message.Message):
    __slots__ = ("authorization", "side", "domain", "participant", "permission", "trust_level")
    AUTHORIZATION_FIELD_NUMBER: _ClassVar[int]
    SIDE_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    TRUST_LEVEL_FIELD_NUMBER: _ClassVar[int]
    authorization: AuthorizationData
    side: _topology_pb2.RequestSide
    domain: str
    participant: str
    permission: _topology_pb2.ParticipantPermission
    trust_level: _topology_pb2.TrustLevel
    def __init__(self, authorization: _Optional[_Union[AuthorizationData, _Mapping]] = ..., side: _Optional[_Union[_topology_pb2.RequestSide, str]] = ..., domain: _Optional[str] = ..., participant: _Optional[str] = ..., permission: _Optional[_Union[_topology_pb2.ParticipantPermission, str]] = ..., trust_level: _Optional[_Union[_topology_pb2.TrustLevel, str]] = ...) -> None: ...

class MediatorDomainStateAuthorization(_message.Message):
    __slots__ = ("authorization", "side", "domain", "mediator")
    AUTHORIZATION_FIELD_NUMBER: _ClassVar[int]
    SIDE_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_FIELD_NUMBER: _ClassVar[int]
    authorization: AuthorizationData
    side: _topology_pb2.RequestSide
    domain: str
    mediator: str
    def __init__(self, authorization: _Optional[_Union[AuthorizationData, _Mapping]] = ..., side: _Optional[_Union[_topology_pb2.RequestSide, str]] = ..., domain: _Optional[str] = ..., mediator: _Optional[str] = ...) -> None: ...

class VettedPackagesAuthorization(_message.Message):
    __slots__ = ("authorization", "participant", "package_ids")
    AUTHORIZATION_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_IDS_FIELD_NUMBER: _ClassVar[int]
    authorization: AuthorizationData
    participant: str
    package_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, authorization: _Optional[_Union[AuthorizationData, _Mapping]] = ..., participant: _Optional[str] = ..., package_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class DomainParametersChangeAuthorization(_message.Message):
    __slots__ = ("authorization", "domain", "parameters_v0", "parameters_v1", "parameters_v2")
    AUTHORIZATION_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_V0_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_V1_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_V2_FIELD_NUMBER: _ClassVar[int]
    authorization: AuthorizationData
    domain: str
    parameters_v0: _sequencing_pb2.DynamicDomainParameters
    parameters_v1: _sequencing_pb2_1.DynamicDomainParameters
    parameters_v2: _domain_params_pb2.DynamicDomainParameters
    def __init__(self, authorization: _Optional[_Union[AuthorizationData, _Mapping]] = ..., domain: _Optional[str] = ..., parameters_v0: _Optional[_Union[_sequencing_pb2.DynamicDomainParameters, _Mapping]] = ..., parameters_v1: _Optional[_Union[_sequencing_pb2_1.DynamicDomainParameters, _Mapping]] = ..., parameters_v2: _Optional[_Union[_domain_params_pb2.DynamicDomainParameters, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class PruneRequest(_message.Message):
    __slots__ = ("prune_up_to", "submission_id", "prune_all_divulged_contracts")
    PRUNE_UP_TO_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    PRUNE_ALL_DIVULGED_CONTRACTS_FIELD_NUMBER: _ClassVar[int]
    prune_up_to: int
    submission_id: str
    prune_all_divulged_contracts: bool
    def __init__(self, prune_up_to: _Optional[int] = ..., submission_id: _Optional[str] = ..., prune_all_divulged_contracts: bool = ...) -> None: ...

class PruneResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .initialization_service_pb2 import CurrentTimeRequest, CurrentTimeResponse, GetIdRequest, GetIdResponse, GetOnboardingTransactionsRequest, GetOnboardingTransactionsResponse, InitIdRequest, InitIdResponse

__all__ = [
    "IdentityInitializationServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class IdentityInitializationServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _IdentityInitializationServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _IdentityInitializationServiceAsyncStub: ...  # type: ignore
    def InitId(self, __1: InitIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[InitIdResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, InitIdResponse]]: ...
    def GetOnboardingTransactions(self, __1: GetOnboardingTransactionsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetOnboardingTransactionsResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetOnboardingTransactionsResponse]]: ...
    def GetId(self, __1: GetIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetIdResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetIdResponse]]: ...
    def CurrentTime(self, __1: CurrentTimeRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[CurrentTimeResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, CurrentTimeResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _IdentityInitializationServiceBlockingStub(IdentityInitializationServiceStub):
    def InitId(self, __1: InitIdRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> InitIdResponse: ...
    def GetOnboardingTransactions(self, __1: GetOnboardingTransactionsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetOnboardingTransactionsResponse: ...
    def GetId(self, __1: GetIdRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetIdResponse: ...
    def CurrentTime(self, __1: CurrentTimeRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> CurrentTimeResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _IdentityInitializationServiceAsyncStub(IdentityInitializationServiceStub):
    def InitId(self, __1: InitIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, InitIdResponse]: ...  # type: ignore
    def GetOnboardingTransactions(self, __1: GetOnboardingTransactionsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetOnboardingTransactionsResponse]: ...  # type: ignore
    def GetId(self, __1: GetIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetIdResponse]: ...  # type: ignore
    def CurrentTime(self, __1: CurrentTimeRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, CurrentTimeResponse]: ...  # type: ignore
